/*!
* unplugin-vue-component-ref v1.0.6
* (c) 2022 zrrz
* @license MIT
*/
'use strict';

var unplugin$1 = require('unplugin');
var pluginutils = require('@rollup/pluginutils');
var compilerSfc = require('@vue/compiler-sfc');
var compilerCore = require('@vue/compiler-core');

const onVnodeBeforeMountRef = ' :onVnodeBeforeMount="onVnodeBeforeMountRef_" ';

const transform = (source, filename) => {
    const { descriptor } = compilerSfc.parse(source);
    if (descriptor.template) {
        const { loc: templateLocStart } = descriptor.template;
        const magicString = new compilerSfc.MagicString(source);
        const onRefNode = (node) => {
            if (node.type === 1 /** NodeTypes.ELEMENT */) {
                const ref = compilerCore.findProp(node, 'ref');
                if (ref && ref.type === 6 /**  NodeTypes.ATTRIBUTE */) {
                    const { loc } = ref;
                    magicString.appendLeft(loc.end.offset + templateLocStart.start.offset, onVnodeBeforeMountRef);
                }
            }
        };
        compilerSfc.compileTemplate({
            filename,
            source: descriptor.template.content,
            id: filename,
            compilerOptions: {
                nodeTransforms: [onRefNode]
            }
        });
        return magicString.toString();
    }
};

function resolveOption(options) {
    return {
        include: options.include || [/\.vue$/],
        exclude: options.exclude || undefined
    };
}
const unplugin = unplugin$1.createUnplugin((userOptions = {}) => {
    const options = resolveOption(userOptions);
    const filter = pluginutils.createFilter(options.include, options.exclude);
    return {
        name: 'unplugin-vue-component-ref',
        enforce: 'pre',
        transformInclude(id) {
            return filter(id);
        },
        transform(code, id) {
            if (filter(id))
                transform(code, id);
            return null;
        }
    };
});
const vitePlugin = unplugin.vite;
const rollupPlugin = unplugin.rollup;
const webpackPlugin = unplugin.webpack;
const esbuildPlugin = unplugin.esbuild;

exports.esbuildPlugin = esbuildPlugin;
exports.rollupPlugin = rollupPlugin;
exports.unplugin = unplugin;
exports.vitePlugin = vitePlugin;
exports.webpackPlugin = webpackPlugin;
